@@ -70,6 +70,7 @@ def profile_connections (data_tweets):
     data_tweets = data_tweets.rename(columns = {"created_at": "created_at_tw"})
     data_tweets = pd.concat([data_tweets.drop(['user'], axis=1), data_tweets['user'].apply(pd.Series)],
                             axis=1).drop_duplicates().reset_index(drop=True)
+    print(data_tweets.dtypes)
     if(data_tweets.empty == False):
         for i in range(len(data_tweets)):
             screen_name.append(data_tweets["screen_name"][i])
@@ -105,6 +106,20 @@ def profile_connections (data_tweets):
                                                                         ascending = False)}).reset_index()
     return data1_ext
 
+def basic_metadata_tweets_extracted (data_tweets, node_list): 
+        
+    data_tweets = data_tweets.rename(columns = {"created_at": "created_at_tw"})
+    df_basic_metadata_tweets_extracted = pd.concat([data_tweets.drop(['user'], axis=1), data_tweets['user'].apply(pd.Series)],
+                            axis=1).drop_duplicates().reset_index(drop=True)[["screen_name","followees","followers","url"]]
+    
+    extract_profiles =[]
+    tweets_profiles =  list(df_basic_metadata_tweets_extracted["screen_name"])
+    for profile in tweets_profiles:
+        for profile not in node_list:
+          extract_profiles.append(profile)
+          
+    return extract_profiles, df_basic_metadata_tweets_extracted
+
 #--------------------------------------Graph building functions---------------------------
 
 def building_node_list(df):
